From 58798c81cfedb2d18e594871e6fdf149c4fc8004 Mon Sep 17 00:00:00 2001
From: Darwin Bautista <djclue917@gmail.com>
Date: Sun, 2 Dec 2007 11:30:42 +0800
Subject: Added autoversioning of dependencies and related options.
 Autoversioning is default but can be disabled using -v or --nodepsver

---
 scripts/makepkg.sh.in |   31 +++++++++++++++++++++++++++++--
 1 files changed, 29 insertions(+), 2 deletions(-)

diff --git a/scripts/makepkg.sh.in b/scripts/makepkg.sh.in
index 953bda2..de742a6 100644
--- a/scripts/makepkg.sh.in
+++ b/scripts/makepkg.sh.in
@@ -54,6 +54,7 @@ INSTALL=0
 NOBUILD=0
 NODEPS=0
 NOEXTRACT=0
+NOVERSIONDEP=0
 RMDEPS=0
 REPKG=0
 LOGGING=0
@@ -440,6 +441,29 @@ remove_deps() {
 	fi
 }
 
+version_dep() {
+	local dep="$*"
+	local depver ret
+
+	if [ -z "$(echo $dep | grep -E '<|=|>')" ]; then
+		depver="$(pacman -Q $dep | cut -d ' ' -f 2)"
+		ret=$?
+
+		if [ $ret -ne 0 ]; then
+			error "$(gettext "Pacman returned a fatal error (%i): %s")" "$ret" "$depver"
+			exit 1
+		fi
+
+		if [ -n "$depver" ]; then
+			echo "$dep>=$depver"
+		else
+			echo "$dep"
+		fi
+	else
+		echo "$dep"
+	fi
+}
+
 download_sources() {
 	msg "$(gettext "Retrieving Sources...")"
 
@@ -817,6 +841,7 @@ create_package() {
 		echo "group = $it" >>.PKGINFO
 	done
 	for it in "${depends[@]}"; do
+		[ "$NOVERSIONDEP" = "0" ] && it=$(version_dep $it)
 		echo "depend = $it" >>.PKGINFO
 	done
 	for it in "${optdepends[@]}"; do
@@ -1059,6 +1084,7 @@ usage() {
 	echo "$(gettext "  -C, --cleancache Clean up source files from the cache")"
 	echo "$(gettext "  -d, --nodeps     Skip all dependency checks")"
 	echo "$(gettext "  -e, --noextract  Do not extract source files (use existing src/ dir)")"
+	echo "$(gettext "  -v, --nodepsver  Do not automatically put the dependencies' versions")"
 	echo "$(gettext "  -f, --force      Overwrite existing package")"
 	echo "$(gettext "  -g, --geninteg   Generate integrity checks for source files")"
 	echo "$(gettext "  -h, --help       This help")"
@@ -1129,8 +1155,8 @@ if [ -z "$SRCROOT" ]; then
 fi
 
 # Parse Command Line Options.
-OPT_SHORT="AbcCdefFghiLmop:rRsSV"
-OPT_LONG="ignorearch,asroot,builddeps,clean,cleancache,nodeps,noextract,force,geninteg,help,install,log"
+OPT_SHORT="AbcCdevfFghiLmop:rRsSV"
+OPT_LONG="ignorearch,asroot,builddeps,clean,cleancache,nodeps,noextract,nodepsver,force,geninteg,help,install,log"
 OPT_LONG="$OPT_LONG,nocolor,nobuild,rmdeps,repackage,source,syncdeps,usesudo,version,forcever:"
 # Pacman Options
 OPT_LONG="$OPT_LONG,noconfirm,noprogressbar"
@@ -1156,6 +1182,7 @@ while true; do
 		-C|--cleancache)  CLEANCACHE=1 ;;
 		-d|--nodeps)      NODEPS=1 ;;
 		-e|--noextract)   NOEXTRACT=1 ;;
+		-v|--nodepsver)   NOVERSIONDEP=1;;
 		-f|--force)       FORCE=1 ;;
 		-F)               INFAKEROOT=1 ;;
 		-g|--geninteg)    GENINTEG=1 ;;
-- 
1.5.3.6

